Developer Guide
===============

Documentation is split into four categories, also accessible from links in the
side-bar.

.. grid:: 2
    :gutter: 4

    .. grid-item-card:: :material-regular:`directions_run;3em`

        .. toctree::
            :caption: Tutorials
            :maxdepth: 1

            tutorials/dev-install

        +++

        Tutorials for getting up and running as a developer.

    .. grid-item-card:: :material-regular:`task;3em`

        .. toctree::
            :caption: How-to Guides
            :maxdepth: 1

            how-to/contribute
            how-to/build-docs
            how-to/run-tests
            how-to/static-analysis
            how-to/lint
            how-to/update-tools
            how-to/make-release
            how-to/pin-requirements
            how-to/test-container

        +++

        Practical step-by-step guides for day-to-day dev tasks.

    .. grid-item-card:: :material-regular:`apartment;3em`

        .. toctree::
            :caption: Explanations
            :maxdepth: 1

            explanations/decisions
            explanations/entities

        +++

        Explanations of how and why the architecture is why it is.

    .. grid-item-card:: :material-regular:`description;3em`

        .. toctree::
            :caption: Reference
            :maxdepth: 1

            reference/standards

        +++

        Technical reference material on standards in use.
